CVS: libraries/include commandline.h,1.5,1.6

Chris Liechti <[email protected]> Mon, 24 Mar 2008 12:00:41 -0700
Newsgroups gmane.comp.hardware.texas-instruments.msp430.gcc.cvs
Message-ID <[email protected]>
Update of /cvsroot/mspgcc/libraries/include
In directory sc8-pr-cvs16.sourceforge.net:/tmp/cvs-serv5153/include

Modified Files:
	commandline.h 
Log Message:
- updated several doxgen comments
- added doxy.conf and make target "doxy" so that library docs can be generated


Index: commandline.h
===================================================================
RCS file: /cvsroot/mspgcc/libraries/include/commandline.h,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -w -d -r1.5 -r1.6
--- commandline.h	24 Mar 2008 16:04:32 -0000	1.5
+++ commandline.h	24 Mar 2008 19:00:39 -0000	1.6
@@ -1,6 +1,19 @@
 #ifndef MSPGCC_COMMANDLINE_H
 #define MSPGCC_COMMANDLINE_H
 
+/**
+ * @file
+ *
+ * Functions to implement a command line interface.
+ */
+
+/**
+\defgroup commandline   Commandline
+
+Functions and definitions for the command line implementation in libcommandline.
+@{
+*/
+
 #include <mspgcc/util.h>
 #include <stdbool.h>
 
@@ -14,10 +27,10 @@
 /**
  * Use the following macro to create entries in the command table.
  * the command function is prefixed with "command_".
  * The help text should be short (<60 characters).
  *
  * @param name          name of the command and it's function
- * @param hlp           short help string
+ * @param hlp           help string
  */
 #define COMMANDLINE_ENTRY(name, hlp) {#name, command_##name, hlp}  //table entry generation
 
@@ -126,11 +139,17 @@
  */
 unsigned int commandline_number(const char *s);
 
-// the library provides a number of commands for the user
-// they just have to be registered in the command_table.
-// note that these functions generate english text outputs on stdout
-// some are also dendant on functions from other libraries
-// (e.g. flash from libmspgcc)
+/**
+\defgroup commandline_commands  Commands provided
+
+The library provides a number of commands for the user
+they just have to be registered in the command_table.
+
+@note These functions generate english text outputs using ::printf
+      and some are also dendent on functions from other libraries
+      (e.g. flash from libmspgcc)
+@{
+*/
 
 /**
  * Print a list of supported commands and their short help.
@@ -212,19 +231,26 @@
 "USAGE: checksum address [size]\n\n" \
 "A simple 16 bit XOR checksum us used."
 
+/** @} */
+
 /**
- * Simple Tab completion. This function can be called when a command should be
- * completed. This function writes to the display using printf/putchar.
+ * Simple command completion. This function can be called when a command should
+ * be completed. This function writes to the display using printf/putchar.
+ *
  * Call thins function when a tab was received, it will automaticaly scan
  * the commandline_table for matches and writes the result to the line buffer.
  * 
- * @param commandline_table     table with commands that can be completed
- * @param lineeditor            the command line, that is edited
- * @param prompt                the prompt is used after a list of command was printed
+ * @param commandline_table     [in] table with commands that can be completed
+ * @param lineeditor            [in] the command line, that is edited
+ * @param prompt                [in] the prompt is used after a list of command
+ *                              was printed
  */
 void commandline_tabcomplete(
     const COMMANDLINE_TABLE *commandline_table,
     LINEEDITOR_STATE *lineeditor,
     const char *prompt
 );
+
+/** @} */
+
 #endif //MSPGCC_COMMANDLINE_H


-------------------------------------------------------------------------
@@ -14,10 +27,10 @@
  * Use the following macro to create entries in the command table.
  * the command function is prefixed with "command_".
- * The help text should be short (<60 characters).
+ * The 1st line in the help text should be short (<60 characters).
  *
  * @param name          name of the command and it's function
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2008.
http://clk.atdmt.com/MRT/go/vse0120000070mrt/direct/01/